/**
* DO NOT EDIT THIS FILE.
* See the following change record for more information,
* https://www.drupal.org/node/2815083
* @preserve
**/

/**
 * @file
 * Javascript to initialize singe date time library.
 */

(function ($, Drupal, drupalSettings) {
  /**
   * Function to return list of hours / minutes formatted as array.
   *
   * @param {Array} $hours
   *   List for allowed hours as array.
   * @param {string} $type
   *   Granularity for allowed intervals in minutes.
   *
   * @return {Array}
   *   Return minutes formatted in array by allowed intervals.
   */
  function SingleDatetimeAllowTimes($hours, $type) {
    var times = [];

    // Build array.
    $hours.forEach(function (i) {
      // Formatting hours.
      if (i < 10) {
        i = "0" + i;
      }

      // Default granularity is one hour.
      if ($type === 60) {
        times.push(i + ":00");
      }

      // Custom settings, per minutes.
      else {
          var measure = 60 / $type;
          for (var j = 0; j < measure; j++) {
            var minutes = $type * j;

            if (j === 0) {
              minutes = "00";
            } else if (minutes < 10) {
              minutes = "0" + minutes;
            }
            times.push(i + ":" + minutes);
          }
        }
    });

    return times;
  }

  /**
   * Attaches the single_datetime behavior.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.single_datetime = {
    attach: function attach(context) {

      // Setting the current language for the calendar.
      var lang = drupalSettings.path.currentLanguage;

      $(context).find("input[data-single-date-time]").once("datePicker").each(function () {
        var input = $(this);

        // Get widget type.
        var widgetType = input.data("singleDateTime");

        // Get hour format - 12 or 24.
        var hourFormat = input.data("hourFormat");

        // Get first day in week from Drupal.
        var dayOfWeekStart = input.data("firstDay");

        // Default values (used for dates only).
        var format = "Y-m-d";
        var allowTimepicker = false;

        // Get disabled days.
        var disabledWeekDays = input.data("disableDays");

        // Get excluded dates.
        var disabledDates = input.data("excludeDate");

        // Get minimum date.
        var minDate = input.data("minDate");

        // Get maximum date.
        var maxDate = input.data("maxDate");

        // Get start year.
        var yearStart = input.data("yearStart");

        // Get end year.
        var yearEnd = input.data("yearEnd");

        // Set the hour format.
        var formatTime = hourFormat === "12h" ? "h:i A" : "H:i";

        var inline = input.data("inline");

        var mask = Boolean(input.data("mask"));

        var theme = input.data("datetimepickerTheme");

        // Default empty array. Only calculate later if field type
        // includes times.
        var allowTimes = [];

        // If is date & time field.
        if (widgetType === "datetime") {
          format = hourFormat === "12h" ? "Y-m-d h:i:s A" : "Y-m-d H:i:s";
          allowTimepicker = true;

          // Get minute granularity, and allowed hours.
          allowTimes = SingleDatetimeAllowTimes(input.data("allowedHours"), input.data("allowTimes"));
        }

        $("#" + input.attr("id")).datetimepicker({
          format: format,
          formatTime: formatTime,
          lazyInit: true,
          timepicker: allowTimepicker,
          todayButton: true,
          dayOfWeekStart: dayOfWeekStart,
          allowTimes: allowTimes,
          disabledWeekDays: disabledWeekDays,
          disabledDates: disabledDates,
          formatDate: "d.m.Y",
          inline: inline,
          mask: mask,
          minDate: minDate,
          maxDate: maxDate,
          yearStart: yearStart,
          yearEnd: yearEnd,
          theme: theme
        });
        // Explicitly set locale. Does not work with passed variable
        // in setttings above.
        $.datetimepicker.setLocale(lang);
      });
    }
  };
})(jQuery, Drupal, drupalSettings);